# Jumpup-deis
[![RubyGems][gem_version_badge]][ruby_gems]
[![Code Climate](https://codeclimate.com/github/Helabs/jumpup-deis.png)](https://codeclimate.com/github/Helabs/jumpup-deis)
[![Dependency Status](https://gemnasium.com/Helabs/jumpup-deis.svg)](https://gemnasium.com/Helabs/jumpup-deis)

Rake tasks to deploy any Rails application to [Deis](http://deis.io/) using [Jumpup](https://github.com/Helabs/jumpup).

## Instalation

Add to your gem file.

```ruby
gem 'jumpup-deis'
```

Without groups on Gemfile as this gem makes use of an initializer.

##  Usage

1. Create the initializer on `config/initializers/jumpup-deis.rb`

  ```ruby
  # config/initializers/jumpup-deis.rb
  Jumpup::Deis.configure do |config|
    config.host = 'deis.mycompany.com'
    config.app  = 'myapp'
  end if Rails.env.development?
  ```

2. Add to the tasks on jumpup.rake the tasks to deploy to Deis:

  ```ruby
  # lib/tasks/jumpup.rake

  INTEGRATION_TASKS = %w(
    jumpup:deis:start
    jumpup:start
    jumpup:bundle_install
    db:migrate
    spec
    jumpup:finish
    jumpup:deis:finish
  )
  ```

### Production and staging apps

Have production and staging app? Do like this:

```ruby
Jumpup::Deis.configure do |config|
  config.host           = 'deis.mycompany.com'
  config.staging_app    = 'myapp-staging'
  config.production_app = 'myapp'
end if Rails.env.development?
```
The branch send to staging app is `master` and the branch send to production is the `production`.

### Deploy to production

#### When I have a single app

Run ```rake jumpup:deis:deploy:production``` or as an alias ```rake integrate:production```

#### When I have staging and production apps

We have the following config

| Branch        | App Environment |
| ------------- |-----------------|
| master        | staging         |
| production    | production      |

So to send to production we need to

```bash
$ git checkout production
$ git merge master
$ git push -u origin production
```

And send to Deis with ```rake jumpup:deis:deploy:production``` or as an alias ```rake integrate:production```

## Versioning

Jumpup-deis follow the [Semantic Versioning](http://semver.org/).

## Issues

If you have problems, please create a [Github Issue](https://github.com/Helabs/jumpup-deis/issues).

## Contributing

Please see [CONTRIBUTING.md](https://github.com/Helabs/jumpup-deis/blob/master/CONTRIBUTING.md) for details.

## Maintainers

- [Anézio Campos](https://github.com/aneziocampos)
- [Rafael Fiuza](https://github.com/guiloyins)

## Release

Follow this steps to release a new version of the gem.

1. Test if everything is running ok;
1. Change version of the gem on `VERSION` constant;
1. Add the release date on the `CHANGELOG`;
1. Do a commit "Bump version x.x.x", follow the semantic version;
1. Run `$ rake release`, this will send the gem to the rubygems;
1. Check if the gem is on the rubygems and the tags are correct on the github;

## Credits

Jumpup-deis is maintained and funded by [HE:labs](http://helabs.com.br/opensource/).
Thank you to all the [contributors](https://github.com/Helabs/jumpup-deis/graphs/contributors).

## License

Jumpup-deis is Copyright © 2014 HE:labs. It is free software, and may be redistributed under the terms specified in the LICENSE file.

[gem_version_badge]: https://badge.fury.io/rb/jumpup-deis.png
[ruby_gems]: http://rubygems.org/gems/jumpup-deis


## Made with love by HE:labs

![HE:labs](http://helabs.com.br/images/logo.png)

This gem was created and is maintained by [HE:labs](https://github.com/Helabs).
