require 'spec_helper'

describe Jumpup::Deis::Configuration do

  before do
    Jumpup::Deis.configuration = nil
  end

  describe ".configure" do
    describe "without configuration" do
      before do
        Jumpup::Deis.configure { |config| nil }
      end

      subject { Jumpup::Deis.configuration }

      describe '#app' do
        subject { super().app }
        it { is_expected.to be_nil }
      end

      describe '#staging_app' do
        subject { super().staging_app }
        it { is_expected.to be_nil }
      end

      describe '#production_app' do
        subject { super().production_app }
        it { is_expected.to be_nil }
      end

      describe '#run_database_tasks' do
        subject { super().run_database_tasks }
        it { is_expected.to be_truthy }
      end

      describe '#host' do
        subject { super().host }
        it { is_expected.to be_nil }
      end

      describe '#deploy_branch' do
        subject { super().deploy_branch }
        it { is_expected.to eq('master') }
      end

      describe '#deploy_to_production_branch' do
        subject { super().deploy_to_production_branch }
        it { is_expected.to eq('master') }
      end
    end

    describe "with configurations" do
      before do
        Jumpup::Deis.configure do |config|
          config.app = 'myapp'
          config.production_app = 'myapp-production'
          config.staging_app = 'myapp-staging'
          config.run_database_tasks = false
          config.host = 'myhost.com'
        end
      end

      subject { Jumpup::Deis.configuration }

      describe '#app' do
        subject { super().app }
        it { is_expected.to eq('myapp') }
      end

      describe '#staging_app' do
        subject { super().staging_app }
        it { is_expected.to eq('myapp-staging')}
      end

      describe '#production_app' do
        subject { super().production_app }
        it { is_expected.to eq('myapp-production') }
      end

      describe '#run_database_tasks' do
        subject { super().run_database_tasks }
        it { is_expected.to be_falsey }
      end

      describe '#host' do
        subject { super().host }
        it { is_expected.to eq('myhost.com') }
      end

      describe '#deploy_branch' do
        subject { super().deploy_branch }
        it { is_expected.to eq('master') }
      end

      describe '#deploy_to_production_branch' do
        subject { super().deploy_to_production_branch }
        it { is_expected.to eq('production') }
      end
    end
  end

  describe "#valid?" do
    describe 'app configs' do
      describe "with app" do
        before do
          Jumpup::Deis.configure do |config|
            config.app = 'myapp'
          end
        end

        it "is invalid" do
          expect(Jumpup::Deis.configuration).to_not be_valid
        end
      end

      describe "with app and host" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.app  = 'myapp'
          end
        end

        it "is valid" do
          expect(Jumpup::Deis.configuration).to be_valid
        end
      end

      describe "with staging_app and production_app" do
        before do
          Jumpup::Deis.configure do |config|
            config.production_app = 'myapp-production'
            config.staging_app = 'myapp-staging'
          end
        end

        it "is invalid" do
          expect(Jumpup::Deis.configuration).to_not be_valid
        end
      end

      describe "with host, staging_app and production_app" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.production_app = 'myapp-production'
            config.staging_app = 'myapp-staging'
          end
        end

        it "is valid" do
          expect(Jumpup::Deis.configuration).to be_valid
        end
      end

      describe "with host, app, staging_app and production_app" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.app = 'myapp'
            config.production_app = 'myapp-production'
            config.staging_app = 'myapp-staging'
          end
        end

        it 'is invalid' do
          expect(Jumpup::Deis.configuration).to_not be_valid
        end
      end

      describe "with host and staging_app" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.staging_app = 'myapp-staging'
          end
        end

        it 'is invalid' do
          expect(Jumpup::Deis.configuration).to_not be_valid
        end
      end

      describe "with host and production_app" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.production_app = 'myapp-production'
          end
        end

        it 'is invalid' do
          expect(Jumpup::Deis.configuration).to_not be_valid
        end
      end

      describe "with host, app and production_app" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.app = 'myapp'
            config.production_app = 'myapp-production'
          end
        end

        it 'is invalid' do
          expect(Jumpup::Deis.configuration).to_not be_valid
        end
      end

      describe "with host, app and staging_app" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.app = 'myapp'
            config.staging_app = 'myapp-staging'
          end
        end

        it 'is not valid' do
          expect(Jumpup::Deis.configuration).to_not be_valid
        end
      end
    end

    describe 'run_database_tasks configs' do
      describe "with true run_database_tasks" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.app = 'myapp'
            config.run_database_tasks = true
          end
        end

        it 'is valid' do
          expect(Jumpup::Deis.configuration).to be_valid
        end
      end

      describe "with false run_database_tasks" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.app = 'myapp'
            config.run_database_tasks = false
          end
        end

        it 'is valid' do
          expect(Jumpup::Deis.configuration).to be_valid
        end
      end

      describe "with invalid run_database_tasks" do
        before do
          Jumpup::Deis.configure do |config|
            config.host = 'host.com'
            config.app = 'myapp'
            config.run_database_tasks = 'a'
          end
        end

        it 'is invalid' do
          expect(Jumpup::Deis.configuration).to_not be_valid
        end
      end
    end

    describe "without configuration" do
      before do
        Jumpup::Deis.configure { |config| nil }
      end

      it 'is invalid' do
        expect(Jumpup::Deis.configuration).to_not be_valid
      end
    end

    describe "with configuration nil" do
      before { Jumpup::Deis.configuration = nil }

      it 'is invalid' do
        pending "The bug is raised when have no config/initialier/deis-deploy.rb file"
        expect(Jumpup::Deis.configuration).to_not be_valid
      end
    end
  end
end
